@@ -18,7 +18,7 @@
 
 #include "ktoolbarhandler_p.h"
 
-#include <QtXml/QDomDocument>
+#include <QDomDocument>
 #include <QAction>
 #include <QMenu>
 
@@ -140,7 +140,7 @@ private:
 
 using namespace KDEPrivate;
 
-class ToolBarHandler::Private
+class Q_DECL_HIDDEN ToolBarHandler::Private
 {
 public:
     Private(ToolBarHandler *_parent)
@@ -169,8 +169,8 @@ void ToolBarHandler::Private::init(KXmlGuiWindow *mw)
 {
     mainWindow = mw;
 
-    QObject::connect(mainWindow->guiFactory(), SIGNAL(clientAdded(KXMLGUIClient*)),
-                     parent, SLOT(clientAdded(KXMLGUIClient*)));
+    QObject::connect(mainWindow->guiFactory(), &KXMLGUIFactory::clientAdded,
+                     parent, &ToolBarHandler::clientAdded);
 
     if (parent->domDocument().documentElement().isNull()) {
 
@@ -190,9 +190,9 @@ void ToolBarHandler::Private::connectToActionContainers()
 
 void ToolBarHandler::Private::connectToActionContainer(QAction *action)
 {
-    uint containerCount = action->associatedWidgets().count();
+    int containerCount = action->associatedWidgets().count();
 
-    for (uint i = 0; i < containerCount; ++i) {
+    for (int i = 0; i < containerCount; ++i) {
         connectToActionContainer(action->associatedWidgets().value(i));
     }
 }
@@ -204,8 +204,8 @@ void ToolBarHandler::Private::connectToActionContainer(QWidget *container)
         return;
     }
 
-    connect(popupMenu, SIGNAL(aboutToShow()),
-            parent, SLOT(setupActions()));
+    connect(popupMenu, &QMenu::aboutToShow,
+            parent, &ToolBarHandler::setupActions);
 }
 
 ToolBarHandler::ToolBarHandler(KXmlGuiWindow *mainWindow)
@@ -267,4 +267,7 @@ void ToolBarHandler::setupActions()
     d->connectToActionContainers();
 }
 
-#include "moc_ktoolbarhandler_p.cpp"
+void ToolBarHandler::clientAdded(KXMLGUIClient* client)
+{
+    d->clientAdded(client);
+}
